package fsl.depict.netcdf;

/**
 * The floating point formatting rule, encapsulating how a
 * particular Netcdf floating point parameter is to be
 * displayed.
 *
 * @author Christopher Golden
 */
public class FloatingPointFormattingRule extends NumberFormattingRule {


	// Protected Variables

	/**
	 * Digits following the decimal place.
	 */
	protected int digitsAfter;

	/**
	 * Minimum value.
	 */
	protected double minValue; 

	/**
	 * Maximum value.
	 */
	protected double maxValue; 


	// Public Constructors

	/**
	 * Construct a standard instance.
	 *
	 * @param id          Identifier of the parameter.
	 * @param placement   Placement around the center
	 *                    point.
	 * @param conversion  Conversion to be performed.
	 * @param digitsAfter Digits following the decimal
	 *                    place.
	 * @param minValue    Minimum allowable value.
	 * @param maxValue    Maximum allowable value.
	 */
	public FloatingPointFormattingRule(String id, int placement, int conversion,
									   int digitsAfter, double minValue,
									   double maxValue) {
		super(id, placement, conversion);
		this.digitsAfter = digitsAfter;
		this.minValue = minValue;
		this.maxValue = maxValue;
	}


	// Public Methods

	/**
	 * Get the number of digits following the decimal
	 * point.
	 *
	 * @return Number of digits following the decimal
	 *         point.
	 */
	public int getDigitsAfter() {
		return digitsAfter;
	}

	/**
	 * Get the minimum value.
	 *
	 * @return Minimum value.
	 */
	public double getMinimumValue() {
		return minValue;
	}

	/**
	 * Get the maximum value.
	 *
	 * @return Maximum value.
	 */
	public double getMaximumValue() {
		return maxValue;
	}
}
