package fsl.depict.netcdf;

/**
 * The integer formatting rule, encapsulating how a particular
 * Netcdf integer parameter is to be displayed.
 *
 * @author Christopher Golden
 */
public class IntegerFormattingRule extends NumberFormattingRule {


	// Protected Variables

	/**
	 * Minimum value.
	 */
	protected int minValue; 

	/**
	 * Maximum value.
	 */
	protected int maxValue; 


	// Public Constructors

	/**
	 * Construct a standard instance.
	 *
	 * @param id         Identifier of the parameter.
	 * @param placement  Placement around the center
	 *                   point.
	 * @param conversion Conversion to be performed.
	 * @param minValue   Minimum allowable value.
	 * @param maxValue   Maximum allowable value.
	 */
	public IntegerFormattingRule(String id, int placement, int conversion,
								 int minValue, int maxValue) {
		super(id, placement, conversion);
		this.minValue = minValue;
		this.maxValue = maxValue;
	}


	// Public Methods

	/**
	 * Get the minimum value.
	 *
	 * @return Minimum value.
	 */
	public int getMinimumValue() {
		return minValue;
	}

	/**
	 * Get the maximum value.
	 *
	 * @return Maximum value.
	 */
	public int getMaximumValue() {
		return maxValue;
	}
}
