#! /bin/sh
#
#---------------------------------------------------------------------
#  Standard Disclaimer
#
#  Forecast Systems Laboratory
#  NOAA/OAR/ERL/FSL
#  325 Broadway
#  Boulder, CO     80303
#
#  AVIATION DIVISION
#  MODEL VERIFICATION AND PRODUCTION ASSISTANCE
#  Model Verification Section
#
#  This software and its documentation are in the public domain and are
#  furnished "as is".  The United States government, its instrumentalities,
#  officers, employees, and agents make no warranty, express or implied,
#  as to the usefulness of the software and documentation for any purpose.
#  They assume no responsibility (1) for the use of the software and
#  documentation; or (2) to provide technical support to users.
#
#  Permission to use, copy, modify, and distribute this software is hereby
#  granted, provided that this disclaimer notice appears in all copies.
#  All modifications to this software must be clearly documented, and are
#  solely the responsibility of the agent making the modification.  If
#  significant modifications or enhancements are made to this software,
#  the FSL Software Policy Manager (softwaremgr@fsl.noaa.gov) should be
#  notified.
#
#---------------------------------------------------------------------
#
# This script sets the impact overrides in the Override tables.
# 
# Input grp_set, seg_id, ovr_seg_impct, start_tm, end_tm.
# Pipe a the list of (seg_id, ovr_seg_impct, start_tm, end_tm) modifications 
# into setOverrides.sh.
#
# PARAMETER 1: EDIT_START_TM=20070330_1900  Start of time range editing.
# PARAMETER 2: EDIT_END_TM=20070330_2100  End of time range editing.
# PARAMETER 3: REQ_NUM_FRMS=25  Requested number of frames to edit.
#              Needed for getting the inventory so can update the images on the website.
#
#EXAMPLE:
# Field names = (map_name, seg_in_map, depict_key, data_name, fcst_min, ovr_seg_impct, start_tm, minutes_from_start_tm)
#  STAR, 200120, DCA_STAR_GATES, ncwf2, -1, 2, YYYYMMDD_HHmm, MinutesFromStart
#
#  fcst_min = -1 means set override for all forecast times of this data_name.
#
#  STAR, 200120, DCA_STAR_GATES, ncwf, 0, 2, 20060926_2144, 10
#  STAR, 200120, DCA_STAR_GATES, ncwf, 60, 2, 20060926_2144, 20
#  STAR, 200120, DCA_STAR_GATES, ncwf2, 0, 2, 20060926_2144, 20
#  STAR, 200120, DCA_STAR_GATES, ncwf2, 30, 1, 20060926_2144, 25
#  STAR, 200120, DCA_STAR_GATES, ncwf2, 60, 0, 20060926_2144, 21
#  STAR, 200120, DCA_STAR_GATES, ncwf2, 90, 1, 20060926_2144, 3
#  STAR, 200120, DCA_STAR_GATES, ncwf2, 120, 0, 20060926_2144, 120
#
# overrides.txt 
#  STAR, 200120, DCA_STAR_GATES, ncwf2, -1, 2, 20060926_2144, 4
#  STAR, 200123, DCA_STAR_GATES, ncwf2, -1, 2, 20060926_2144, 27
#  STAR, 200121, DCA_STAR_GATES, ncwf2, -1, 1, 20060926_1144, 52
#  SID, 200320, DCA_STAR_GATES, ncwf2, -1, 0, 20060926_1822, 120
#  AWY, 100120, DCA_STAR_GATES, ncwf2, -1, 2, 20060926_0144, 30
#
# overrides.txt (NEW)
# 1,00FF00,33.4506,-96.5969,33.265,-96.3328,DFW,TRACON,500005,120016,ncwf2,FF0000,20070320_1900,4
# 1,00FF00,32.2842,-97.4797,32.4581,-97.7139,DFW,TRACON,500007,120016,ncwf2,00FF00,20070320_1924,0
# 1,00FF00,33.3172,-97.7342,33.4511,-97.5506,DFW,TRACON,500004,120016,ncwf2,FFFF00,20070320_2044,16
# 1,00FF00,32.4675,-96.3325,32.2856,-96.5828,DFW,TRACON,500006,120016,ncwf2,FF0000,20070320_1940,40
#
# ./setOverrides.sh "${EDIT_START_TM}" "${EDIT_END_TM}" "${REQ_NUM_FRMS}" /dirpath/FAAOverrides.txt
# ./setOverrides.sh 20070330_1900 20070330_2100 25 /dirpath/FAAOverrides.txt
#
#
# 03-20-07     C. E. Steffen  
########################################


OLD_DIR=`pwd`
cd "${FXA_HOME}/bin/aiDBCode"


START_TM_NSEC=`date -u +%s%N`


EDIT_START_TM=20070330_1900
if test -n "${1}"
then
    EDIT_START_TM="${1}" 
fi

EDIT_END_TM=20070330_2100
if test -n "${2}"
then
    EDIT_END_TM="${2}" 
fi

REQ_NUM_FRMS=25
if test -n "${3}"
then
    REQ_NUM_FRMS="${3}" 
fi

OVER_RIDES_FILE="/tmp/FAAOverrides.txt"
if test -n "${4}"
then
   OVER_RIDES_FILE="${4}"
fi


# Add Logic to test if OVER_RIDES_FILE exists.
# If it doesn't than exit with an error code
# FXC will pick up and display that code in
# the server manager window or scriptServer log file.

DATABASE_NAME=aiDBtest
export DATABASE_NAME
. "./envVars.sh"

# WARNING: READ THIS: IMPORTANT: YOU MUST Redirect Standard Out and Standard Error
# when calling setImgsAndOverrides.sh below. &>/dev/null
# Also, best to turn off all AWIPS tty logging (though not required).
# Though this seems trivial ... If we do not redirect than FXC locks up since 
# it has a problem getting a return or closing the output channel from this script. 
# (not really sure which it is yet or why.)
# 
./setImgsAndOverrides.sh "${DATABASE_NAME}" "${EDIT_START_TM}" "${EDIT_END_TM}" "${REQ_NUM_FRMS}" < "${OVER_RIDES_FILE}" &>/dev/null 

END_TM_NSEC=`date -u +%s%N`
EXE_TM=`expr "${END_TM_NSEC}" - "${START_TM_NSEC}"`
#echo "setOverrides.sh EXECUTE TIME = ${EXE_TM} nanosecs"

cd "${OLD_DIR}"
